import os
from pathlib import Path
from dedal.configuration.GpgConfig import GpgConfig
from dedal.enum.SpackViewEnum import SpackViewEnum
from dedal.model import SpackDescriptor
from dedal.utils.utils import resolve_path


class SpackConfig:
    def __init__(self, env: SpackDescriptor = None, repos: list[SpackDescriptor] = None,
                 install_dir=Path(os.getcwd()).resolve(), upstream_instance=None, system_name=None,
                 concretization_dir: Path = None, buildcache_dir: Path = None, gpg: GpgConfig = None,
                 use_spack_global=False, cache_version_concretize='v1',
                 cache_version_build='v1', view=SpackViewEnum.VIEW, override_cache=True, bashrc_path=os.path.expanduser("~/.bashrc")):
        self.env = env
        if repos is None:
            self.repos = []
        else:
            self.repos = repos
        self.upstream_instance = upstream_instance
        self.system_name = system_name
        self.concretization_dir = concretization_dir if concretization_dir is None else resolve_path(concretization_dir)
        self.buildcache_dir = buildcache_dir if buildcache_dir is None else resolve_path(buildcache_dir)
        self.install_dir = resolve_path(install_dir)
        self.gpg = gpg
        self.use_spack_global = use_spack_global
        self.cache_version_concretize = cache_version_concretize
        self.cache_version_build = cache_version_build
        self.view = view
        self.override_cache = override_cache
        self.bashrc_path = bashrc_path

    def add_repo(self, repo: SpackDescriptor):
        if self.repos is None:
            self.repos = []
        else:
            self.repos.append(repo)
