class SpackException(Exception):

    def __init__(self, message):
        super().__init__(message)
        self.message = str(message)

    def __str__(self):
        return self.message


class BashCommandException(SpackException):
    """
    To be thrown when a bash command has failed
    """


class NoSpackEnvironmentException(BashCommandException):
    """
    To be thrown when an operation on a spack environment is executed without the environment being activated or existent
    """


class SpackConcertizeException(BashCommandException):
    """
    To be thrown when the spack concretization step fails
    """


class SpackInstallPackagesException(BashCommandException):
    """
    To be thrown when the spack fails to install spack packages
    """


class SpackMirrorException(BashCommandException):
    """
    To be thrown when the spack add mirror command fails
    """


class SpackGpgException(BashCommandException):
    """
    To be thrown when the spack fails to create gpg keys
    """


class SpackRepoException(BashCommandException):
    """
    To be thrown when the spack fails to add a repo
    """


class SpackReindexException(BashCommandException):
    """
    To be thrown when the spack reindex step fails
    """


class SpackSpecException(BashCommandException):
    """
    To be thrown when the spack spec for a package fails
    """


class SpackConfigException(BashCommandException):
    """
    To be thrown when the spack config command fails
    """

class SpackFindException(BashCommandException):
    """
    To be thrown when the spack find command fails
    """