import os

from dedal.configuration.SpackConfig import SpackConfig
from dedal.spack_factory.SpackOperation import SpackOperation
from dedal.spack_factory.SpackOperationCreateCache import SpackOperationCreateCache
from dedal.spack_factory.SpackOperationUseCache import SpackOperationUseCache


class SpackOperationCreator:
    @staticmethod
    def get_spack_operator(spack_config: SpackConfig = None, use_cache: bool = False) -> SpackOperation:
        env_vars_concretization_cache = [
            os.environ.get('CONCRETIZE_OCI_HOST'),
            os.environ.get('CONCRETIZE_OCI_PROJECT'),
            os.environ.get('CONCRETIZE_OCI_USERNAME'),
            os.environ.get('CONCRETIZE_OCI_PASSWORD'),
        ]
        env_vars_build_cache = [
            os.environ.get('BUILDCACHE_OCI_HOST'),
            os.environ.get('BUILDCACHE_OCI_PROJECT'),
            os.environ.get('BUILDCACHE_OCI_USERNAME'),
            os.environ.get('BUILDCACHE_OCI_PASSWORD')
        ]
        if spack_config is None:
            return SpackOperation()
        elif None in env_vars_concretization_cache and None in env_vars_build_cache:
            return SpackOperation(spack_config)
        elif spack_config.concretization_dir is None and spack_config.buildcache_dir is None:
            return SpackOperation(spack_config)
        elif (spack_config.concretization_dir and spack_config.buildcache_dir) and not use_cache:
            return SpackOperationCreateCache(spack_config)
        elif (spack_config.concretization_dir and spack_config.buildcache_dir) and use_cache:
            return SpackOperationUseCache(spack_config)
        else:
            return SpackOperation(SpackConfig())
