from pathlib import Path

import pytest

from dedal.configuration.GpgConfig import GpgConfig
from dedal.configuration.SpackConfig import SpackConfig

from dedal.model.SpackDescriptor import SpackDescriptor
from dedal.spack_factory.SpackOperationCreateCache import SpackOperationCreateCache
from dedal.spack_factory.SpackOperationCreator import SpackOperationCreator
from dedal.tests.integration_tests.helper import check_installed_spack_packages
from dedal.tests.testing_variables import test_spack_env_git, ebrains_spack_builds_git

"""
Before running those tests, the repositories where the caching is stored must be cleared after each run. 
Ebrains Harbour does not support deletion via API, so the clean up must be done manually
"""


def setup(path):
    install_dir = path
    concretization_dir = install_dir / 'concretization'
    buildcache_dir = install_dir / 'buildcache'
    env = SpackDescriptor('test-spack-env', install_dir, test_spack_env_git)
    repo = SpackDescriptor('ebrains-spack-builds', install_dir, ebrains_spack_builds_git)
    gpg = GpgConfig(gpg_name='test-gpg', gpg_mail='test@test.com')
    config = SpackConfig(env=env, install_dir=install_dir, concretization_dir=concretization_dir,
                         buildcache_dir=buildcache_dir, gpg=gpg)
    config.add_repo(repo)
    spack_operation = SpackOperationCreator.get_spack_operator(config)
    return spack_operation


@pytest.mark.skip(
    reason="Skipping until an OCI registry which supports via API deletion; Clean up for OCI registry repo must be added before this test.")
def test_spack_create_cache_concretization(tmp_path):
    install_dir = tmp_path
    spack_operation = setup(install_dir)
    assert isinstance(spack_operation, SpackOperationCreateCache)
    spack_operation.install_spack(bashrc_path=str(tmp_path / Path('.bashrc')))
    spack_operation.setup_spack_env()
    spack_operation.concretize_spack_env()
    assert len(spack_operation.cache_dependency.list_tags()) > 0


@pytest.mark.skip(
    reason="Skipping until an OCI registry which supports via API deletion; Clean up for OCI registry repo must be added before this test.")
def test_spack_create_cache_installation(tmp_path):
    install_dir = tmp_path
    spack_operation = setup(install_dir)
    assert isinstance(spack_operation, SpackOperationCreateCache)
    spack_operation.install_spack(bashrc_path=str(install_dir / Path('.bashrc')))
    spack_operation.setup_spack_env()
    spack_operation.concretize_spack_env()
    assert len(spack_operation.cache_dependency.list_tags()) > 0
    spack_operation.install_packages()
    assert len(spack_operation.build_cache.list_tags()) > 0
    check_installed_spack_packages(spack_operation, tmp_path)
