from dedal.utils.utils import set_bashrc_variable


def test_add_new_variable(tmp_path):
    var_name = 'TEST_VAR'
    value = 'test_value'
    bashrc_path = tmp_path / ".bashrc"
    bashrc_path.touch()
    set_bashrc_variable(var_name, value, bashrc_path=str(bashrc_path))
    content = bashrc_path.read_text()
    assert f'export {var_name}={value}' in content


def test_update_existing_variable(tmp_path):
    var_name = 'TEST_VAR'
    value = 'test_value'
    updated_value = 'new_value'
    bashrc_path = tmp_path / ".bashrc"
    bashrc_path.write_text(f'export {var_name}={value}\n')
    set_bashrc_variable(var_name, updated_value, bashrc_path=str(bashrc_path), update_variable=True)
    content = bashrc_path.read_text()
    assert f'export {var_name}={updated_value}' in content
    assert f'export {var_name}={value}' not in content


def test_do_not_update_existing_variable(tmp_path):
    var_name = 'TEST_VAR'
    value = 'test_value'
    new_value = 'new_value'
    bashrc_path = tmp_path / ".bashrc"
    bashrc_path.write_text(f'export {var_name}={value}\n')

    set_bashrc_variable(var_name, new_value, bashrc_path=str(bashrc_path), update_variable=False)

    content = bashrc_path.read_text()
    assert f'export {var_name}={value}' in content
    assert f'export {var_name}={new_value}' not in content


def test_add_variable_with_special_characters(tmp_path):
    var_name = 'TEST_VAR'
    value = 'value_with_$pecial_chars'
    escaped_value = 'value_with_\\$pecial_chars'
    bashrc_path = tmp_path / ".bashrc"
    bashrc_path.touch()

    set_bashrc_variable(var_name, value, bashrc_path=str(bashrc_path))

    content = bashrc_path.read_text()
    assert f'export {var_name}={escaped_value}' in content
