import yaml
import re


def extract_spack_packages(spack_yaml_path: str):
    """
    Extracts only the package names from a spack.yaml file, ignoring versions, variants, compilers, and dependencies.
    Args:
        spack_yaml_path (str): Path to the spack.yaml file.
    Returns:
        List[str]: Clean list of package names.
    """
    with open(spack_yaml_path, 'r') as f:
        data = yaml.safe_load(f)
    specs = data.get('spack', {}).get('specs', [])
    package_names = []
    for spec in specs:
        if isinstance(spec, str):
            # Match the first word-like token before any of: @ + % ^ whitespace
            match = re.match(r'^([\w-]+)', spec.strip())
            if match:
                package_names.append(match.group(1))

    return package_names
